LogDropNetworkLogger class

Main SDK class to initialize network interception. It uses HttpOverrides to inject a custom HttpClient into the application.

Constructors

LogDropNetworkLogger()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

init() → void
Initializes the logger. It wraps any existing HttpOverrides to ensure compatibility with other tools.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

setLogCallback(HttpLogCallback? callback) → void