saveCrashReport static method

dynamic saveCrashReport(
  1. String threadName,
  2. String stackTrace,
  3. String crashType
)

Saves a crash report to the native platform for later transmission.

threadName The name of the thread where the crash occurred. stackTrace The stack trace associated with the crash. crashType The type or category of the crash.

Implementation

static saveCrashReport(
    String threadName,
    String stackTrace,
    String crashType,
    ) {
  _channel.invokeMethod(MethodNames.saveCrashReport, {
    'threadName': threadName,
    'stackTrace': stackTrace,
    'crashType': crashType,
  });
}