setCustomAttributes static method

Future<void> setCustomAttributes(
  1. Map<String, String> attributes
)

Adds or updates custom user attributes used for push segmentation.

The attributes are merged with the currently stored attributes. The native SDK validates and persists the complete mutation before syncing it with the backend.

Implementation

static Future<void> setCustomAttributes(
  Map<String, String> attributes,
) async {
  await _channel.invokeMethod(MethodNames.setCustomAttributes, {
    'attributes': attributes,
  });
}