NetworkActivityData class
Constructors
-
NetworkActivityData({required bool isSuccess, required String uuid, required String method, required String url, required Map<
String, String> requestHeaders, dynamic requestBody, int? status, Map<String, String> ? responseHeaders, dynamic responseBody, int? tookMs, String? errorType, String? errorMessage})
Properties
- errorMessage → String?
-
final
- errorType → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isSuccess → bool
-
final
- method → String
-
final
- requestBody → dynamic
-
final
-
requestHeaders
→ Map<
String, String> -
final
- responseBody → dynamic
-
final
-
responseHeaders
→ Map<
String, String> ? -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int?
-
final
- tookMs → int?
-
final
- url → String
-
final
- uuid → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited